@@ -1,8 +1,8 @@
-__version__ = "0.2.2"
+__version__ = "0.2.3"
 
 from .repr_str import *
 from .repr_rgb import *
-# from lovely_tensors.repr_plt import *
+from .repr_plt import *
 from .repr_chans import *
 from .lo import *
 from .utils import *
\ No newline at end of file
